@@ -2,9 +2,12 @@
 #'
 #' \code{DAGintervention} takes a DAG or a sampled chain of DAGs (for example from
 #' the \code{\link[BiDAG]{partitionMCMC}} function of the BiDAG package) and computes the
-#' intervention effect of each node on all others by exhaustively
-#' examining all possible binary states. This is exponentially complex in the
-#' number of variables which should therefore be limited to around 20 or fewer.
+#' intervention effect of each node on all others. For binary data, this is performed
+#' by exhaustively examining all possible binary states. This is exponentially complex in the
+#' number of variables which should therefore be limited to around 20 or fewer. For more
+#' variables there is a Monte Carlo version \code{\link{DAGinterventionMC}} instead.
+#' For continuous data, the intervention estimation is performed by extracting the edge coefficients from 
+#' their posterior distribution and using matrix inversion following arXiv:2010.00684.
 #'
 #' @param incidences a single adjacency matrix of a list of adjacency matrices of
 #' sampled DAGs, with entry [i,j] equal to 1 when a directed edge exists from
@@ -37,13 +40,15 @@ DAGintervention <- function(incidences, dataParams, sample = TRUE){
 
   n <- ncol(incidences[[1]]) # number of nodes in DAG
   
-  if (n > 20) {
-    warning("Exhaustive enumeration may not be feasible")
-  }
+  if (dataParams$type == "bde") { # only for BDe version
+    if (n > 20) {
+      warning("Exhaustive enumeration may not be feasible")
+    }
 
-  allBinaryVecs <- matrix(0, 2^n, n)
-  for (ii in 1:2^n) {
-    allBinaryVecs[ii, ] <- as.integer(intToBits(ii-1))[n:1]
+    allBinaryVecs <- matrix(0, 2^n, n)
+    for (ii in 1:2^n) {
+      allBinaryVecs[ii, ] <- as.integer(intToBits(ii-1))[n:1]
+    }
   }
 
   numDAGs <- length(incidences)
@@ -53,12 +58,20 @@ DAGintervention <- function(incidences, dataParams, sample = TRUE){
     DAGparams <- DAGparameters(incidences[[kk]], dataParams)
 
     DAGparamsInternal <- DAGparams
-    if(sample==TRUE){ # then we take a sample of parameters from the posterior instead of taking the expectation
-      DAGparamsInternal$pmeans <- SampleParameters(DAGparams)
-    }
+    if (dataParams$type == "bde") { # only for BDe version
+      if(sample==TRUE){ # then we take a sample of parameters from the posterior instead of taking the expectation
+        DAGparamsInternal$pmeans <- SampleParameters(DAGparams)
+      }
 
-    allLogScores <- BinaryScoreAgainstDAG(DAGparamsInternal, allBinaryVecs)
-    interventionMats[[kk]] <- InterventionEstimation(allLogScores, allBinaryVecs)
+      allLogScores <- BinaryScoreAgainstDAG(DAGparamsInternal, allBinaryVecs)
+      interventionMats[[kk]] <- InterventionEstimation(allLogScores, allBinaryVecs)
+    } else { # bge version
+      if(sample==TRUE){ # then we take a sample of parameters from the posterior instead of taking the expectation
+        DAGparamsInternal$mus <- SampleParameters(DAGparams, type = "bge")
+      }
+      
+      interventionMats[[kk]] <- InterventionEstimationBGe(DAGparamsInternal)
+    }
   }
 
   if (numDAGs == 1) { # turn back to single matrix
@@ -69,7 +82,7 @@ DAGintervention <- function(incidences, dataParams, sample = TRUE){
 }
 
 
-
+# this function is no longer needed
 DAGinterventionparams <- function(DAGparams, sample = TRUE){
   # this wrapper takes in a DAG with parameters and returns all intervention effects
 
@@ -93,6 +106,25 @@ DAGinterventionparams <- function(DAGparams, sample = TRUE){
 
 
 
+InterventionEstimationBGe <- function(DAGparams){
+  # estimate intervention effects from edge coefficients
+  
+  n <- ncol(DAGparams$DAG) # number of nodes
+  
+  coeffMatrix <- matrix(0, nrow=n, ncol=n)
+  for (j in 1:n) {
+    parentNodes <- which(DAGparams$DAG[, j]==1)
+    if (length(parentNodes) > 0) {
+      coeffMatrix[parentNodes, j] <- DAGparams$mus[[j]]
+    }
+  }
+  
+  interventionMatrix <- solve(diag(n) - coeffMatrix) # adding all paths with the inverse
+  return(interventionMatrix)
+}
+
+
+
 InterventionEstimation <- function(logScores, dataToScore){
   # estimate intervention effects from the scores of all binary vectors
 
