@@ -1,9 +1,10 @@
 #' Monte Carlo estimation of intervention effects for a DAG or chain of sampled DAGs
 #'
 #' \code{DAGinterventionMC} takes a DAG or a sampled chain of DAGs (for example from
-#' the \code{\link[BiDAG]{partitionMCMC}} function of the BiDAG package) and computes a Monte Carlo
-#' estimate of the intervention effect of each node on all others by simulating data
-#' from the DAG. By default each node is intervened upon and the downstream effects
+#' the \code{\link[BiDAG]{partitionMCMC}} function of the BiDAG package) and computes,
+#' for binary data, a Monte Carlo estimate of the intervention effect of 
+#' each node on all others by simulating data from the DAG. 
+#' By default each node is intervened upon and the downstream effects
 #' estimated by further sampling. A faster but less robust and accurate version is
 #' also offered which reweights a single simulated dataset.
 #'
@@ -38,11 +39,15 @@
 DAGinterventionMC <- function(incidences, dataParams, sampleSize, sample = TRUE, fixNode = TRUE, reducedVarianceSampling = TRUE){
   # this wrapper takes in a chain of DAG, computes their parameters and returns all MC intervention effects
 
-  if(sampleSize < 1e3) {
+  if (sampleSize < 1e3) {
     sampleSize <- 1e3
     warning("Setting sample size to a minimum of 1000.")
   }
 
+  if (dataParams$type != "bde") {
+    stop("Only implemented for the BDe score.")
+  }
+  
   if (!is.list(incidences)) { # turn to list internally
     incidences <- list(incidences)
   }
